@@ -20,7 +20,7 @@ use JSON;
 use URI::Template;
 use RDF::LDF::Error;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 {
    my $ua   = RDF::Trine->default_useragent;
    $ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
@@ -634,6 +634,12 @@ RDF::LDF - Linked Data Fragments client
     use RDF::Trine::Store::LDF;
     use RDF::Trine::Store;
 
+    # To use a HTTP cache:
+    use LWP::UserAgent::CHICaching;
+    my $cache = CHI->new( driver => 'Memory', global => 1 );
+    my $ua = LWP::UserAgent::CHICaching->new(cache => $cache);
+    RDF::Trine->default_useragent($ua);
+
     my $store = RDF::Trine::Store->new_with_config({
             storetype => 'LDF',
             url => $url
